package com.util.crypto_util;

import androidx.annotation.NonNull;

import java.util.Map;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.CharsetUtil;
import cn.hutool.core.util.StrUtil;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * CryptoUtilPlugin
 */
public class CryptoUtilPlugin implements FlutterPlugin, MethodCallHandler {
    private MethodChannel channel;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "crypto_util");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        String data = null;
        String resultData = null;
        switch (call.method) {
            case "encryptSM4":
                Map<String, Object> arguments = Convert.toMap(String.class, Object.class, call.arguments);
                data = MapUtil.getStr(arguments, "data");
                String key = MapUtil.getStr(arguments, "key");
                resultData = Crypto.encryptSM4(key, data);
                result.success(resultData);
                break;
            case "encryptSM2":
                data = StrUtil.str(call.arguments, CharsetUtil.UTF_8);
                resultData = Crypto.encryptSM2(data);
                result.success(resultData);
                break;
            case "generateKey":
                data = StrUtil.str(call.arguments, CharsetUtil.UTF_8);
                resultData = Crypto.generateKey(data);
                result.success(resultData);
                break;
            default:
                result.notImplemented();
                break;
        }

    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
